CHANGES
=======

0.0.4 (2023-09-01)
------------------

- Update supported Python versions to 3.8 or later.
- Use new style classes.
- Migrate to pyproject.toml.

0.0.3 (2016-04-25)
------------------

Thanks to `@lukius <https://github.com/lukius>`_ .

- Support for one-sided (min/max) tests.
- Test output is now more flexible: the user can run the test in order to find the outliers themselves or the indices of the outliers, and not just the outlier-free data.
- Test suite was enhanced.
- README was extended and improved.
- Japanese comments were translated to English so as to reach a greater audience.

0.0.2 (2015-12-02)
------------------

Update setup.py

0.0.1 (2015-12-01)
------------------

Publish to pypi

0.0.0 (2015-07-28)
------------------

Create this project.

